@@ -509,41 +509,6 @@ def create_side_by_side_plot(coords: pd.DataFrame, classifications: np.ndarray,
     return fig
 
 
-def save_classification_csv(coords: pd.DataFrame, classifications: np.ndarray, 
-                          max_probs: np.ndarray, class_names: List[str],
-                          output_path: str) -> None:
-    """
-    Save classification results to CSV file.
-    
-    Args:
-        coords (pd.DataFrame): Spatial coordinates
-        classifications (np.ndarray): Classification labels
-        max_probs (np.ndarray): Maximum classification probabilities
-        class_names (list): Cell type names
-        output_path (str): Output CSV file path
-    """
-    # Prepare data
-    df = pd.DataFrame({
-        'x': coords['x'],
-        'y': coords['y'],
-        'cell_labels': classifications,
-        'confidence': max_probs
-    })
-    
-    # Add class names
-    df['class_name'] = df['cell_labels'].apply(
-        lambda x: class_names[x] if x != -1 and x < len(class_names) else 'Unclassified'
-    )
-    
-    # Sort: classified cells first, then unclassified
-    classified_df = df[df['cell_labels'] != -1].sort_values('cell_labels')
-    unclassified_df = df[df['cell_labels'] == -1]
-    df_sorted = pd.concat([classified_df, unclassified_df], ignore_index=True)
-    
-    # Save to CSV
-    df_sorted.to_csv(output_path, index=False)
-    logging.info(f"Classification data saved to: {output_path}")
-
 
 def process_roi_visualization(roi_name: str, roi_coords: Tuple[float, float, float, float],
                             args: argparse.Namespace, class_names: List[str],
@@ -629,10 +594,7 @@ def process_roi_visualization(roi_name: str, roi_coords: Tuple[float, float, flo
         except Exception as e:
             logging.warning(f"Failed to process background image for {roi_name}: {e}")
     
-    # Save classification CSV
-    csv_path = os.path.join(args.output_dir, f"Spatial_Classification_{safe_roi_name}_data.csv")
-    save_classification_csv(coords_roi, classifications_roi, max_probs_roi, 
-                           renamed_class_names, csv_path)
+
 
 
 def save_figures_with_auto_mkdir(figures: List[plt.Figure], 
@@ -860,7 +822,7 @@ This tool generates comprehensive visualizations including:
 - Scatter plots of spatial classification
 - Background image overlays
 - Side-by-side comparisons
-- Classification data CSV exports
+
         """
     )
     
