@@ -75,19 +75,19 @@ if (!(celltype_col %in% colnames(meta))) {
 }
 
 # Cell types for analysis
-SuScs_celltypes <- c("Immature osteoblast", "Axin2⁺-SuSC", "Pro-inflammatory dural fibroblast", "Chondrocyte","Ectocranial SM", "Pre-osteoblasts", "Outer dural fibroblast",  "Ligament-like mesenchyme","Neural progenitor cell", "Gli1⁺-SuSC", "Capillary endothelial cell","Pericyte", "Mature  osteoblast","Mmp13⁺-Pre-osteoblast",  "Neuron", "Glial cell", "Naive B cell", "M2 Macrophage", "M1 Macrophage", "Proliferating preosteoblast", "Arachnoid fibroblast", "Proliferating B cell", "Proliferating meningeal fibroblasts", "Inner dural fibroblast", "Mast cell", "Neutrophil","Osteoclast")
+SuScs_celltypes <- c("Immature osteoblast", "Axin2⁺-SuSC", "Pro-inflammatory dural fibroblast", "Chondrocyte","Ectocranial SM", "Pre-osteoblasts", "Outer dural fibroblast",  "Ligament-like mesenchyme","Neural progenitor cell", "Gli1⁺-SuSC", "Capillary endothelial cell","Pericyte", "Mature  osteoblast","Mmp13⁺-Pre-osteoblast",  "Neuron", "Glial cell", "Naive B cell", "M2 Macrophage", "M1 Macrophage", "Proliferating preosteoblast", "Arachnoid fibroblast", "Proliferating B cell", "Proliferating meningeal fibroblast", "Inner dural fibroblast", "Mast cell", "Neutrophil","Osteoclast")
 
 # Function to process cell types
 process_cell <- function(counts, meta, celltype_col, cells) {
   read_celltypes <- function() {
-    color_file <- "../utils/color_schemes.py"
-    if (file.exists(color_file)) {
-      lines <- readLines(color_file)
+    unified_file <- "../utils/color_schemes.py"
+    if (file.exists(unified_file)) {
+      lines <- readLines(unified_file)
       celltype_line <- grep('c\\("Mast cell"', lines, value = TRUE)
       if (length(celltype_line) > 0) {
         text <- celltype_line[1]
         parts <- unlist(strsplit(text, '"'))
-		celltypes <- parts[seq(2, length(parts), by = 2)]
+        celltypes <- parts[seq(2, length(parts), by = 2)]
         if (length(celltypes) > 0) {
           return(celltypes)
         }
@@ -119,25 +119,26 @@ process_cell <- function(counts, meta, celltype_col, cells) {
     SuSCs_counts <- counts[, SuSCs_cells]
     SuSCs_meta <- meta[SuSCs_cells, ]
     celltype_counts <- table(SuSCs_meta[[celltype_col]])
+    celltype_counts <- celltype_counts[celltype_counts > 0]
     ordered_celltypes <- names(sort(celltype_counts, decreasing = FALSE))
     celltype_names <- read_celltypes()
     
     if (!is.null(celltype_names) && length(celltype_names) == length(ordered_celltypes)) {
       celltype_map <- setNames(celltype_names, ordered_celltypes)    
       SuSCs_meta_map <- SuSCs_meta
-      SuSCs_meta_map[[celltype_col]] <- celltype_map[SuSCs_meta[[celltype_col]]]    
-      ordered_indices <- order(match(SuSCs_meta_map[[celltype_col]], celltype_names))    
+      original_celltypes <- as.character(SuSCs_meta[[celltype_col]])
+      SuSCs_meta_map[[celltype_col]] <- celltype_map[original_celltypes]
+      
       return(list(
-        counts = SuSCs_counts[, ordered_indices], 
-        meta = SuSCs_meta_map[ordered_indices, ], 
-        cells = SuSCs_cells[ordered_indices]
+        counts = SuSCs_counts, 
+        meta = SuSCs_meta_map, 
+        cells = SuSCs_cells
       ))
     } else {
-      ordered_indices <- order(match(SuSCs_meta[[celltype_col]], ordered_celltypes))
       return(list(
-        counts = SuSCs_counts[, ordered_indices], 
-        meta = SuSCs_meta[ordered_indices, ], 
-        cells = SuSCs_cells[ordered_indices]
+        counts = SuSCs_counts, 
+        meta = SuSCs_meta, 
+        cells = SuSCs_cells
       ))
     }
   } else {
